Struct substrate_wasm_builder::WasmBuilderSelectProject [−][src]
pub struct WasmBuilderSelectProject { /* fields omitted */ }Expand description
First step of the WasmBuilder to select the project to build.
Implementations
Use the current project as project for building the WASM binary.
Panics
Panics if the CARGO_MANIFEST_DIR variable is not set. This variable
is always set by Cargo in build.rs files.
Use the given path as project for building the WASM binary.
Returns an error if the given path does not points to a Cargo.toml.